@@ -9,9 +9,10 @@ use Carp::Heavy           ();
 use Carp                  ();
 use Sub::Uplevel          ();
 use Aspect::Advice        ();
+use Aspect::Advice::Hook  ();
 use Aspect::AdviceContext ();
 
-our $VERSION = '0.38';
+our $VERSION = '0.39';
 our @ISA     = 'Aspect::Advice';
 
 # NOTE: To simplify debugging of the generated code, all injected string
@@ -61,6 +62,8 @@ sub _install {
 		# Generate the new function
 		no warnings 'redefine';
 		eval <<"END_PERL"; die $@ if $@;
+		package Aspect::Advice::Hook;
+
 		*$NAME = sub $PROTOTYPE {
 			# Is this a lexically scoped hook that has finished
 			goto &\$original if $MATCH_DISABLED;
@@ -74,6 +77,7 @@ sub _install {
 				] };
 
 				my \$runtime = {
+					wantarray    => \$wantarray,
 					return_value => \$return,
 					exception    => \$\@,
 				};
@@ -84,12 +88,11 @@ sub _install {
 
 				# Create the context
 				my \$context = Aspect::AdviceContext->new(
-					type      => 'after',
-					pointcut  => \$pointcut,
-					sub_name  => \$name,
-					wantarray => \$wantarray,
-					params    => \\\@_,
-					original  => \$original,
+					type     => 'after',
+					pointcut => \$pointcut,
+					sub_name => \$name,
+					params   => \\\@_,
+					original => \$original,
 					\%\$runtime,
 				);
 
@@ -117,6 +120,7 @@ sub _install {
 				};
 
 				my \$runtime = {
+					wantarray    => \$wantarray,
 					return_value => \$return,
 					exception    => \$\@,
 				};
@@ -127,12 +131,11 @@ sub _install {
 
 				# Create the context
 				my \$context = Aspect::AdviceContext->new(
-					type      => 'after',
-					pointcut  => \$pointcut,
-					sub_name  => \$name,
-					wantarray => \$wantarray,
-					params    => \\\@_,
-					original  => \$original,
+					type     => 'after',
+					pointcut => \$pointcut,
+					sub_name => \$name,
+					params   => \\\@_,
+					original => \$original,
 					\%\$runtime,
 				);
 
@@ -154,6 +157,7 @@ sub _install {
 				};
 
 				my \$runtime = {
+					wantarray    => \$wantarray,
 					return_value => undef,
 					exception    => \$\@,
 				};
@@ -164,12 +168,11 @@ sub _install {
 
 				# Create the context
 				my \$context = Aspect::AdviceContext->new(
-					type      => 'after',
-					pointcut  => \$pointcut,
-					sub_name  => \$name,
-					wantarray => \$wantarray,
-					params    => \\\@_,
-					original  => \$original,
+					type     => 'after',
+					pointcut => \$pointcut,
+					sub_name => \$name,
+					params   => \\\@_,
+					original => \$original,
 					\%\$runtime,
 				);
 
