@@ -9,9 +9,10 @@ use Carp::Heavy           ();
 use Carp                  ();
 use Sub::Uplevel          ();
 use Aspect::Advice        ();
+use Aspect::Advice::Hook  ();
 use Aspect::AdviceContext ();
 
-our $VERSION = '0.38';
+our $VERSION = '0.39';
 our @ISA     = 'Aspect::Advice';
 
 # NOTE: To simplify debugging of the generated code, all injected string
@@ -61,12 +62,16 @@ sub _install {
 		# Generate the new function
 		no warnings 'redefine';
 		eval <<"END_PERL"; die $@ if $@;
+		package Aspect::Advice::Hook;
+
 		*$NAME = sub $PROTOTYPE {
 			# Is this a lexically scoped hook that has finished
 			goto &\$original if $MATCH_DISABLED;
 
-			my \$runtime   = {};
 			my \$wantarray = wantarray;
+			my \$runtime   = {
+				wantarray => \$wantarray,
+			};
 			if ( \$wantarray ) {
 				my \$return = [
 					Sub::Uplevel::uplevel(
@@ -80,7 +85,6 @@ sub _install {
 					type         => 'after_returning',
 					pointcut     => \$pointcut,
 					sub_name     => \$name,
-					wantarray    => \$wantarray,
 					params       => \\\@_,
 					return_value => \$return,
 					original     => \$original,
